@@ -89,6 +89,9 @@ macro_rules! as_num_method {
 ///     Ok(())
 /// }
 /// ```
+///
+/// For default value on map type, [`Node::get`] method has a shorten method [`Node::get_default`] to combining
+/// transform function and default function as well.
 #[derive(Eq, Clone)]
 pub struct Node {
     /// Document position
@@ -190,18 +193,27 @@ impl Node {
         fn as_str = Str | ("")? -> &str
     }
 
-    as_method! {
-        /// Convert to string pointer for string, null, int, and float type.
-        ///
-        /// This method is useful when the option mixed with digit values.
-        ///
-        /// ```
-        /// use yaml_peg::node;
-        /// assert_eq!("abc", node!("abc").as_value().unwrap());
-        /// assert_eq!("123", node!(123).as_value().unwrap());
-        /// assert!(node!(null).as_value().unwrap().is_empty());
-        /// ```
-        fn as_value = Str | ("")? | Int | Float -> &str
+    /// Convert to string pointer for string, null, bool, int, and float type.
+    ///
+    /// This method is useful when the option mixed with digit values.
+    ///
+    /// ```
+    /// use yaml_peg::node;
+    /// assert_eq!("abc", node!("abc").as_value().unwrap());
+    /// assert_eq!("123", node!(123).as_value().unwrap());
+    /// assert_eq!("12.04", node!(12.04).as_value().unwrap());
+    /// assert_eq!("true", node!(true).as_value().unwrap());
+    /// assert_eq!("false", node!(false).as_value().unwrap());
+    /// assert!(node!(null).as_value().unwrap().is_empty());
+    /// ```
+    pub fn as_value(&self) -> Result<&str, u64> {
+        match &self.yaml {
+            Yaml::Str(s) | Yaml::Int(s) | Yaml::Float(s) => Ok(s),
+            Yaml::Bool(true) => Ok("true"),
+            Yaml::Bool(false) => Ok("false"),
+            Yaml::Null => Ok(""),
+            _ => Err(self.pos),
+        }
     }
 
     as_method! {
@@ -246,7 +258,7 @@ impl Node {
 
     /// Convert to map and try to get the value by keys recursivly.
     ///
-    /// If get failed, returns [`Option::None`].
+    /// If any key is missing, return `Err` with node position.
     ///
     /// ```
     /// use yaml_peg::node;
@@ -277,6 +289,55 @@ impl Node {
             _ => Err(self.pos),
         }
     }
+
+    /// Same as [`Node::get`] but provide default value if the key is missing.
+    /// For this method, a transform method `as_*` is required.
+    ///
+    /// + If the value exist, return the value.
+    /// + If value is a wrong type, return `Err` with node position.
+    /// + If the value is not exist, return the default value.
+    ///
+    /// ```
+    /// use yaml_peg::{node, Node};
+    /// let a = node!({node!("a") => node!({node!("b") => node!("c")})});
+    /// assert_eq!(
+    ///     "c",
+    ///     a.get_default(&["a", "b"], "d", Node::as_str).unwrap()
+    /// );
+    /// let b = node!({node!("a") => node!({})});
+    /// assert_eq!(
+    ///     "d",
+    ///     b.get_default(&["a", "b"], "d", Node::as_str).unwrap()
+    /// );
+    /// let c = node!({node!("a") => node!({node!("b") => node!(20.)})});
+    /// assert_eq!(
+    ///     Err(0),
+    ///     c.get_default(&["a", "b"], "d", Node::as_str)
+    /// );
+    /// ```
+    pub fn get_default<'a, Y, R, F>(&'a self, keys: &[Y], default: R, factory: F) -> Result<R, u64>
+    where
+        Y: Into<Yaml> + Copy,
+        F: Fn(&'a Self) -> Result<R, u64>,
+    {
+        if keys.is_empty() {
+            panic!("invalid search!");
+        }
+        match &self.yaml {
+            Yaml::Map(m) => {
+                if let Some(n) = m.get(&node!(keys[0])) {
+                    if keys[1..].is_empty() {
+                        factory(n)
+                    } else {
+                        n.get_default(&keys[1..], default, factory)
+                    }
+                } else {
+                    Ok(default)
+                }
+            }
+            _ => Err(self.pos),
+        }
+    }
 }
 
 impl Debug for Node {
