@@ -5,9 +5,10 @@ pub enum TakeOpt {
     /// Match once.
     One,
     /// Match in range. Same as regex `{a,b}`.
+    /// `Range(0, 1)` is same as regex `?`.
     Range(usize, usize),
     /// Match until mismatched.
-    /// `More(0)` is same as regex `*`, and `More(1)` is same as regex `?`.
+    /// `More(0)` is same as regex `*`, and `More(1)` is same as regex `+`.
     More(usize),
 }
 
@@ -123,7 +124,12 @@ impl Parser<'_> {
 
     /// Match symbol.
     pub fn sym(&mut self, s: u8) -> Result<(), ()> {
-        self.take_while(Self::is_in(&[s]), TakeOpt::One)
+        self.sym_set(&[s])
+    }
+
+    /// Match symbol from a set.
+    pub fn sym_set(&mut self, s: &[u8]) -> Result<(), ()> {
+        self.take_while(Self::is_in(s), TakeOpt::One)
     }
 
     /// Match sequence.
